@@ -4,7 +4,7 @@
 package Lingua::Interset::FeatureStructure;
 use strict;
 use warnings;
-our $VERSION = '2.033';
+our $VERSION = '2.034';
 
 use utf8;
 use open ':utf8';
@@ -592,13 +592,14 @@ my %matrix = @_matrix =
     'degree' =>
     {
         'priority' => 230,
-        'values' => ['pos', 'comp', 'sup', 'abs', ''],
+        'values' => ['pos', 'comp', 'sup', 'abs', 'dim', ''],
         'replacements' =>
         [
             ['pos'],
             ['comp'],
             ['sup', 'comp'],
-            ['abs', 'sup']
+            ['abs', 'sup'],
+            ['dim']
         ],
         'uname' => 'Degree'
     },
@@ -836,6 +837,20 @@ my %matrix = @_matrix =
         ],
         'uname' => 'Gender[dat]'
     },
+    # Position / usage of adjectives, determiners, participles etc.
+    'position' =>
+    {
+        'priority' => 411,
+        'values' => ['prenom', 'postnom', 'nom', 'free', ''],
+        'replacements' =>
+        [
+            ['prenom'],
+            ['postnom'],
+            ['nom'],
+            ['free']
+        ],
+        'uname' => 'Position'
+    },
     # Subcategorization.
     # So far this feature only keeps the transitive-intransitive distinction encoded in some tagsets.
     # However, real verb subcategorization is in fact much more complex.
@@ -1626,6 +1641,7 @@ sub is_gerund {my $self = shift; return $self->contains('verbform', 'ger');}
 sub is_hyph {my $self = shift; return $self->hyph() eq 'hyph';}
 sub is_infinitive {my $self = shift; return $self->contains('verbform', 'inf');}
 sub is_interjection {my $self = shift; $self->contains('pos', 'int');}
+sub is_interrogative {my $self = shift; $self->contains('prontype', 'int');}
 sub is_masculine {my $self = shift; return $self->contains('gender', 'masc');}
 sub is_modal {my $self = shift; return $self->contains('verbtype', 'mod');}
 sub is_negative {my $self = shift; return $self->contains('negativeness', 'neg') || $self->prontype() eq 'neg';} # prontype: don't use contains() here, we don't want true on 'ind|tot|neg'
@@ -1643,6 +1659,7 @@ sub is_pronoun {my $self = shift; return $self->prontype() ne '';}
 sub is_proper_noun {my $self = shift; return $self->contains('nountype', 'prop');}
 sub is_punctuation {my $self = shift; return $self->contains('pos', 'punc');}
 sub is_reflexive {my $self = shift; return $self->reflex() eq 'reflex';}
+sub is_relative {my $self = shift; $self->contains('prontype', 'rel');}
 sub is_singular {my $self = shift; return $self->contains('number', 'sing');}
 sub is_subordinator {my $self = shift; return $self->is_conjunction() && $self->conjtype() eq 'sub';}
 sub is_superlative {my $self = shift; return $self->contains('degree', 'sup');}
@@ -2264,7 +2281,7 @@ Lingua::Interset::FeatureStructure - Definition of morphosyntactic features and
 
 =head1 VERSION
 
-version 2.033
+version 2.034
 
 =head1 SYNOPSIS
 
@@ -2541,6 +2558,8 @@ if C<get_joined('pos') eq 'noun|adj'>.
 
 =head2 is_interjection()
 
+=head2 is_interrogative()
+
 =head2 is_masculine()
 
 =head2 is_modal()
@@ -2575,6 +2594,8 @@ if C<get_joined('pos') eq 'noun|adj'>.
 
 =head2 is_reflexive()
 
+=head2 is_relative()
+
 =head2 is_singular()
 
 =head2 is_subordinator()
